#pragma once

#ifndef  _SRC_MNSDK_DEFINE_H_
#define _SRC_MNSDK_DEFINE_H_

#define MAX_COUNT		10
#define MAX_CH_COUNT	256
#define MAX_ALM_TYPE	10
#define MAX_FAN_COUNT	5

#define WM_NEW_CONNECTION	 WM_USER+10
#define WM_CLIENT_DISCONNECTED WM_NEW_CONNECTION+2
#define WM_SERVER_PORT_OPEN		WM_USER+311

#define WM_ALARM_RECEIVE_EVENT WM_USER+1101

#define MAX_USER_CLIENT_COUNT		20

typedef enum{ // Alarm Type
	almFAN=0, almCPU_LOAD, almCPU_TEMP, almCPU_VCore, almFAN1, almFAN2, almFAN3, almFAN4, almSYS_TEMP, almPERIPH_TEMP
} TEnumAlarmType;

typedef enum{ // Alarm State
	NORMAL_STATE=0, HIGH_WARNNING, LOW_WARNNING, HIGH_ALARM, LOW_ALARM
} TEnumAlarm;

typedef enum{ // PC Type
	PC_PMC=0, PC_CTC=1, PC_FDC=2, PC_TMC=3, PC_MTC=4
};

typedef enum{
	SRC_4128=1, SRC_8128=2, SRC_616=4, SRC_508=8, SRC_4128B=0x10, SRC_604=0x20
};

//////////////////////////////////////////////////////////////////////////
// DATA STRUCTURE
//////////////////////////////////////////////////////////////////////////
#pragma pack(1)
// PC  ü -------------------------------------------------------------- 
typedef struct
{
	char PCName[MAX_CH_COUNT]; // PC ̸
	char OSName[MAX_CH_COUNT]; // OS ̸
	char BDName[MAX_CH_COUNT];
} TPCInfo;

// MainBoard  ü -------------------------------------------------------------- 
typedef struct  
{
	float CPUVCore; // V
	float CPUVCoreMax; // V

	float BDAVcc; // V
	float BDAVccMax; // V

	float BD3Vcc; // V
	float BD3VccMax; // V

	float CPUVCoreState;
	float BDAVccState;
	float BD3VccState;
}TVoltageStatus;

typedef struct  
{
	int FanCount;
	float FanRPM[MAX_FAN_COUNT]; // Fan RPM (  : RPM )
	float FanRPMMax[MAX_FAN_COUNT]; // Fan Max RPM (  : RPM )
	int FanState[MAX_FAN_COUNT]; // Fan RPM  ˶ 
} TFanStatus;

// CPU  ü -------------------------------------------------------------- 
typedef struct
{
	char CPUName[MAX_CH_COUNT];
	char CPUVendor[MAX_CH_COUNT];
	int CoreCount;
} TCPUInfo;

typedef struct  
{
	double CPUTotalLoad; // %
	double CPUTotalLoadMax; // %

	double CPUCoreLoad[MAX_COUNT]; // %
	double CPUCoreLoadMax[MAX_COUNT]; // %

	double CPUTemp;  // 
	double TempMax; // 

	int CPULoadState;
	int TempState;
} TCpuStatus;

// Memory  ü -------------------------------------------------------------- 
typedef struct
{
	float TotalPhys; // MB
	float AvailPhys; // MB
	float UsedPhys; // MB

	float MemLoad; // %
	float MemLoadMax; // %
} TMemoryStatus;

// Hard Disk  ü -------------------------------------------------------------- 
typedef struct
{
	int DiskIdx; //  ũ  ε
	int DriveMask; // ش ũ Ƽ  ( bit 0 - 'A:\', bit 1 - 'B:\' ... )
	char Name[MAX_CH_COUNT];
	float TotalVolume; // MB
} TDiskInfo;

typedef struct
{
	int DiskIdx; // ̺갡  ϵ ũ ε
	char Name[MAX_CH_COUNT];
	float TotalVolume; // MB
} TDriveInfo;

typedef struct 
{
	int DiskCount; //  ϵũ 
	TDiskInfo Disk[MAX_COUNT];

	int DriveCount; //  ϵũ ̺ 
	TDriveInfo Drive[MAX_COUNT];
} THddInfo;

typedef struct  
{
	float AvailVolume; // MB
	float UsedVolume; // MB
} THddStatus;

//   ü -------------------------------------------------------------- 

typedef struct
{
	TVoltageStatus VoltageStatus;
	TFanStatus FanStatus;
	TCpuStatus CpuStatus;
	TMemoryStatus MemoryStatus;
	THddStatus DriveStatus[MAX_COUNT];
	THddStatus DiskStatus[MAX_COUNT];
} TMonitorStatus;

// Board  ü ----------------------------------------------
typedef struct  
{
	int nPCType;
	int nNumDevs;
	int nDevsList[3];
} TPCBoardInfo;

// ˶  ü ----------------------------------------------
typedef struct
{
	float CPUVCore_HighAlarm; //   CPU VCore Value ū
	float CPUVCore_LowAlarm; //   CPU VCore Valur 
	float FanRPM_HighAlarm;  //   Fan RPM Value ū
	float FanRPM_LowAlarm; //   Fan RPM Value 
	double CPULoad_HighAlarm; //   CPU Load value ū
	double CPULoad_LowAlarm; //   CPU Load value 
	double Temp_HighAlarm; //   CPU Temperature value ū
	double Temp_LowAlarm; //   CPU Temperature value 

	float CPUVCoreWarningPer; // CPU VCore Warning Percent (  : % )
	float FanRPMWarningPer;  // Fan RPM Warning Percent (  : % )
	float CPULoadWarningPer;  // CPU  Warning Percent (  : % )
	float TempWarningPer;  // CPU µ Warning Percent (  : % )
} TmnCondition;

//////////////////////////////////////////////////////////////////////////
typedef struct  
{
	int PCType; // PMC, CTC, FDC, TMC
	int DevList[10];
	int nDevLoadMask;
	int nDevInterfaceMask;
} TSRCDeviceData;
//////////////////////////////////////////////////////////////////////////

typedef struct
{
	TSRCDeviceData SRCData;

	TPCInfo PCInfo;
	TCPUInfo CPUInfo;
	THddInfo HddInfo;
} TResInfo;

typedef struct  
{
	TMonitorStatus MonitorStatus;
	TmnCondition Condition;
} TResMonData;
//////////////////////////////////////////////////////////////////////////
typedef struct  
{
	bool bIsConnect;

	int FanCount;
	int FanState[MAX_FAN_COUNT];
	int CPULoadState;
	int TempState;
	int CPUVCoreState;
} TAlarmState;

typedef struct  
{
	int nAlarmCount; // ˶ ߻ 
	int nPCIdx[MAX_PATH]; // ˶ ߻ PC ID ( Local = -1 )
	int nAlarmType[MAX_PATH]; // ˶ Ÿ ( TEnumAlarmType  )
	int nAlarmState[MAX_PATH]; // ˶  ( TEnumAlarm  )
	bool bDisconnect[MAX_PATH]; //    ( FALSE = , TRUE =   )
} TEventAlarmRet;

typedef struct  
{
	char PCName[20];
	char AlarmName[20];
	int AlarmState;
	bool IsDisconnect;
} TSAlarmData;

#pragma pack(1)
//////////////////////////////////////////////////////////////////////////
// ERROR CODE
//////////////////////////////////////////////////////////////////////////
#define mncERR_NONE							0
#define mncERR_INVALID_PARAMETER		-1000
#define mncERR_INVALID_SERVER_ID		-1001
#define mncERR_NO_CONNECTION			-6000
#define mncERR_SERVER_COUNT_IS_ZERO	-6004
#define mncERR_CONNECT_FAIL				-8000
#define mncERR_COMM_FAIL					-8001
#define mnERR_DISCONNECTED				-8002
#define mncERR_THREAD_CREATE_FAIL		-9000

#endif